1. Cubes — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »

# 1. Cubes

This chapter describes how to define your own cubes and reuse already available cubes.

- 1.1. Standard structure for a cube
- 1.2. Creating a new cube from scratch using cubicweb-ctl newcube
- 1.3. Available cubes

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »